# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: utxorpc/v1alpha/watch/watch.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'utxorpc/v1alpha/watch/watch.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from utxorpc_spec.utxorpc.v1alpha.cardano import cardano_pb2 as utxorpc_dot_v1alpha_dot_cardano_dot_cardano__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!utxorpc/v1alpha/watch/watch.proto\x12\x15utxorpc.v1alpha.watch\x1a google/protobuf/field_mask.proto\x1a%utxorpc/v1alpha/cardano/cardano.proto\"4\n\x08\x42lockRef\x12\x14\n\x05index\x18\x01 \x01(\x04R\x05index\x12\x12\n\x04hash\x18\x02 \x01(\x0cR\x04hash\"\\\n\x11\x41nyChainTxPattern\x12>\n\x07\x63\x61rdano\x18\x01 \x01(\x0b\x32\".utxorpc.v1alpha.cardano.TxPatternH\x00R\x07\x63\x61rdanoB\x07\n\x05\x63hain\"\xf9\x01\n\x0bTxPredicate\x12>\n\x05match\x18\x01 \x01(\x0b\x32(.utxorpc.v1alpha.watch.AnyChainTxPatternR\x05match\x12\x34\n\x03not\x18\x02 \x03(\x0b\x32\".utxorpc.v1alpha.watch.TxPredicateR\x03not\x12\x39\n\x06\x61ll_of\x18\x03 \x03(\x0b\x32\".utxorpc.v1alpha.watch.TxPredicateR\x05\x61llOf\x12\x39\n\x06\x61ny_of\x18\x04 \x03(\x0b\x32\".utxorpc.v1alpha.watch.TxPredicateR\x05\x61nyOf\"\xcc\x01\n\x0eWatchTxRequest\x12@\n\tpredicate\x18\x01 \x01(\x0b\x32\".utxorpc.v1alpha.watch.TxPredicateR\tpredicate\x12\x39\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\tfieldMask\x12=\n\tintersect\x18\x03 \x03(\x0b\x32\x1f.utxorpc.v1alpha.watch.BlockRefR\tintersect\"N\n\nAnyChainTx\x12\x37\n\x07\x63\x61rdano\x18\x01 \x01(\x0b\x32\x1b.utxorpc.v1alpha.cardano.TxH\x00R\x07\x63\x61rdanoB\x07\n\x05\x63hain\"\x8f\x01\n\x0fWatchTxResponse\x12\x39\n\x05\x61pply\x18\x01 \x01(\x0b\x32!.utxorpc.v1alpha.watch.AnyChainTxH\x00R\x05\x61pply\x12\x37\n\x04undo\x18\x02 \x01(\x0b\x32!.utxorpc.v1alpha.watch.AnyChainTxH\x00R\x04undoB\x08\n\x06\x61\x63tion2j\n\x0cWatchService\x12Z\n\x07WatchTx\x12%.utxorpc.v1alpha.watch.WatchTxRequest\x1a&.utxorpc.v1alpha.watch.WatchTxResponse0\x01\x42\xd2\x01\n\x19\x63om.utxorpc.v1alpha.watchB\nWatchProtoP\x01Z3github.com/utxorpc/go-codegen/utxorpc/v1alpha/watch\xa2\x02\x03UVW\xaa\x02\x15Utxorpc.V1alpha.Watch\xca\x02\x15Utxorpc\\V1alpha\\Watch\xe2\x02!Utxorpc\\V1alpha\\Watch\\GPBMetadata\xea\x02\x17Utxorpc::V1alpha::Watchb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'utxorpc.v1alpha.watch.watch_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.utxorpc.v1alpha.watchB\nWatchProtoP\001Z3github.com/utxorpc/go-codegen/utxorpc/v1alpha/watch\242\002\003UVW\252\002\025Utxorpc.V1alpha.Watch\312\002\025Utxorpc\\V1alpha\\Watch\342\002!Utxorpc\\V1alpha\\Watch\\GPBMetadata\352\002\027Utxorpc::V1alpha::Watch'
  _globals['_BLOCKREF']._serialized_start=133
  _globals['_BLOCKREF']._serialized_end=185
  _globals['_ANYCHAINTXPATTERN']._serialized_start=187
  _globals['_ANYCHAINTXPATTERN']._serialized_end=279
  _globals['_TXPREDICATE']._serialized_start=282
  _globals['_TXPREDICATE']._serialized_end=531
  _globals['_WATCHTXREQUEST']._serialized_start=534
  _globals['_WATCHTXREQUEST']._serialized_end=738
  _globals['_ANYCHAINTX']._serialized_start=740
  _globals['_ANYCHAINTX']._serialized_end=818
  _globals['_WATCHTXRESPONSE']._serialized_start=821
  _globals['_WATCHTXRESPONSE']._serialized_end=964
  _globals['_WATCHSERVICE']._serialized_start=966
  _globals['_WATCHSERVICE']._serialized_end=1072
# @@protoc_insertion_point(module_scope)
