# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: utxorpc/v1alpha/query/query.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'utxorpc/v1alpha/query/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from utxorpc_spec.utxorpc.v1alpha.cardano import cardano_pb2 as utxorpc_dot_v1alpha_dot_cardano_dot_cardano__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!utxorpc/v1alpha/query/query.proto\x12\x15utxorpc.v1alpha.query\x1a google/protobuf/field_mask.proto\x1a%utxorpc/v1alpha/cardano/cardano.proto\"4\n\nChainPoint\x12\x12\n\x04slot\x18\x01 \x01(\x04R\x04slot\x12\x12\n\x04hash\x18\x02 \x01(\x0cR\x04hash\"2\n\x06TxoRef\x12\x12\n\x04hash\x18\x01 \x01(\x0cR\x04hash\x12\x14\n\x05index\x18\x02 \x01(\rR\x05index\"N\n\x11ReadParamsRequest\x12\x39\n\nfield_mask\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\tfieldMask\"X\n\x0e\x41nyChainParams\x12<\n\x07\x63\x61rdano\x18\x01 \x01(\x0b\x32 .utxorpc.v1alpha.cardano.PParamsH\x00R\x07\x63\x61rdanoB\x08\n\x06params\"\x95\x01\n\x12ReadParamsResponse\x12=\n\x06values\x18\x01 \x01(\x0b\x32%.utxorpc.v1alpha.query.AnyChainParamsR\x06values\x12@\n\nledger_tip\x18\x02 \x01(\x0b\x32!.utxorpc.v1alpha.query.ChainPointR\tledgerTip\"f\n\x0e\x41nyUtxoPattern\x12\x44\n\x07\x63\x61rdano\x18\x01 \x01(\x0b\x32(.utxorpc.v1alpha.cardano.TxOutputPatternH\x00R\x07\x63\x61rdanoB\x0e\n\x0cutxo_pattern\"\xfe\x01\n\rUtxoPredicate\x12;\n\x05match\x18\x01 \x01(\x0b\x32%.utxorpc.v1alpha.query.AnyUtxoPatternR\x05match\x12\x36\n\x03not\x18\x02 \x03(\x0b\x32$.utxorpc.v1alpha.query.UtxoPredicateR\x03not\x12;\n\x06\x61ll_of\x18\x03 \x03(\x0b\x32$.utxorpc.v1alpha.query.UtxoPredicateR\x05\x61llOf\x12;\n\x06\x61ny_of\x18\x04 \x03(\x0b\x32$.utxorpc.v1alpha.query.UtxoPredicateR\x05\x61nyOf\"\xb7\x01\n\x0b\x41nyUtxoData\x12!\n\x0cnative_bytes\x18\x01 \x01(\x0cR\x0bnativeBytes\x12\x36\n\x07txo_ref\x18\x02 \x01(\x0b\x32\x1d.utxorpc.v1alpha.query.TxoRefR\x06txoRef\x12=\n\x07\x63\x61rdano\x18\x03 \x01(\x0b\x32!.utxorpc.v1alpha.cardano.TxOutputH\x00R\x07\x63\x61rdanoB\x0e\n\x0cparsed_state\"\x80\x01\n\x10ReadUtxosRequest\x12\x31\n\x04keys\x18\x01 \x03(\x0b\x32\x1d.utxorpc.v1alpha.query.TxoRefR\x04keys\x12\x39\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\tfieldMask\"\x8f\x01\n\x11ReadUtxosResponse\x12\x38\n\x05items\x18\x01 \x03(\x0b\x32\".utxorpc.v1alpha.query.AnyUtxoDataR\x05items\x12@\n\nledger_tip\x18\x02 \x01(\x0b\x32!.utxorpc.v1alpha.query.ChainPointR\tledgerTip\"\x93\x01\n\x12SearchUtxosRequest\x12\x42\n\tpredicate\x18\x01 \x01(\x0b\x32$.utxorpc.v1alpha.query.UtxoPredicateR\tpredicate\x12\x39\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\tfieldMask\"\x91\x01\n\x13SearchUtxosResponse\x12\x38\n\x05items\x18\x01 \x03(\x0b\x32\".utxorpc.v1alpha.query.AnyUtxoDataR\x05items\x12@\n\nledger_tip\x18\x02 \x01(\x0b\x32!.utxorpc.v1alpha.query.ChainPointR\tledgerTip\"`\n\x0fReadDataRequest\x12\x12\n\x04keys\x18\x01 \x03(\x0cR\x04keys\x12\x39\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\tfieldMask\"\x95\x01\n\rAnyChainDatum\x12!\n\x0cnative_bytes\x18\x01 \x01(\x0cR\x0bnativeBytes\x12\x10\n\x03key\x18\x02 \x01(\x0cR\x03key\x12?\n\x07\x63\x61rdano\x18\x03 \x01(\x0b\x32#.utxorpc.v1alpha.cardano.PlutusDataH\x00R\x07\x63\x61rdanoB\x0e\n\x0cparsed_state\"\x92\x01\n\x10ReadDataResponse\x12<\n\x06values\x18\x01 \x03(\x0b\x32$.utxorpc.v1alpha.query.AnyChainDatumR\x06values\x12@\n\nledger_tip\x18\x02 \x01(\x0b\x32!.utxorpc.v1alpha.query.ChainPointR\tledgerTip2\x94\x03\n\x0cQueryService\x12\x61\n\nReadParams\x12(.utxorpc.v1alpha.query.ReadParamsRequest\x1a).utxorpc.v1alpha.query.ReadParamsResponse\x12^\n\tReadUtxos\x12\'.utxorpc.v1alpha.query.ReadUtxosRequest\x1a(.utxorpc.v1alpha.query.ReadUtxosResponse\x12\x64\n\x0bSearchUtxos\x12).utxorpc.v1alpha.query.SearchUtxosRequest\x1a*.utxorpc.v1alpha.query.SearchUtxosResponse\x12[\n\x08ReadData\x12&.utxorpc.v1alpha.query.ReadDataRequest\x1a\'.utxorpc.v1alpha.query.ReadDataResponseB\xd2\x01\n\x19\x63om.utxorpc.v1alpha.queryB\nQueryProtoP\x01Z3github.com/utxorpc/go-codegen/utxorpc/v1alpha/query\xa2\x02\x03UVQ\xaa\x02\x15Utxorpc.V1alpha.Query\xca\x02\x15Utxorpc\\V1alpha\\Query\xe2\x02!Utxorpc\\V1alpha\\Query\\GPBMetadata\xea\x02\x17Utxorpc::V1alpha::Queryb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'utxorpc.v1alpha.query.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.utxorpc.v1alpha.queryB\nQueryProtoP\001Z3github.com/utxorpc/go-codegen/utxorpc/v1alpha/query\242\002\003UVQ\252\002\025Utxorpc.V1alpha.Query\312\002\025Utxorpc\\V1alpha\\Query\342\002!Utxorpc\\V1alpha\\Query\\GPBMetadata\352\002\027Utxorpc::V1alpha::Query'
  _globals['_CHAINPOINT']._serialized_start=133
  _globals['_CHAINPOINT']._serialized_end=185
  _globals['_TXOREF']._serialized_start=187
  _globals['_TXOREF']._serialized_end=237
  _globals['_READPARAMSREQUEST']._serialized_start=239
  _globals['_READPARAMSREQUEST']._serialized_end=317
  _globals['_ANYCHAINPARAMS']._serialized_start=319
  _globals['_ANYCHAINPARAMS']._serialized_end=407
  _globals['_READPARAMSRESPONSE']._serialized_start=410
  _globals['_READPARAMSRESPONSE']._serialized_end=559
  _globals['_ANYUTXOPATTERN']._serialized_start=561
  _globals['_ANYUTXOPATTERN']._serialized_end=663
  _globals['_UTXOPREDICATE']._serialized_start=666
  _globals['_UTXOPREDICATE']._serialized_end=920
  _globals['_ANYUTXODATA']._serialized_start=923
  _globals['_ANYUTXODATA']._serialized_end=1106
  _globals['_READUTXOSREQUEST']._serialized_start=1109
  _globals['_READUTXOSREQUEST']._serialized_end=1237
  _globals['_READUTXOSRESPONSE']._serialized_start=1240
  _globals['_READUTXOSRESPONSE']._serialized_end=1383
  _globals['_SEARCHUTXOSREQUEST']._serialized_start=1386
  _globals['_SEARCHUTXOSREQUEST']._serialized_end=1533
  _globals['_SEARCHUTXOSRESPONSE']._serialized_start=1536
  _globals['_SEARCHUTXOSRESPONSE']._serialized_end=1681
  _globals['_READDATAREQUEST']._serialized_start=1683
  _globals['_READDATAREQUEST']._serialized_end=1779
  _globals['_ANYCHAINDATUM']._serialized_start=1782
  _globals['_ANYCHAINDATUM']._serialized_end=1931
  _globals['_READDATARESPONSE']._serialized_start=1934
  _globals['_READDATARESPONSE']._serialized_end=2080
  _globals['_QUERYSERVICE']._serialized_start=2083
  _globals['_QUERYSERVICE']._serialized_end=2487
# @@protoc_insertion_point(module_scope)
