# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: utxorpc/v1alpha/sync/sync.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'utxorpc/v1alpha/sync/sync.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from utxorpc_spec.utxorpc.v1alpha.cardano import cardano_pb2 as utxorpc_dot_v1alpha_dot_cardano_dot_cardano__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1futxorpc/v1alpha/sync/sync.proto\x12\x14utxorpc.v1alpha.sync\x1a google/protobuf/field_mask.proto\x1a%utxorpc/v1alpha/cardano/cardano.proto\"4\n\x08\x42lockRef\x12\x14\n\x05index\x18\x01 \x01(\x04R\x05index\x12\x12\n\x04hash\x18\x02 \x01(\x0cR\x04hash\"w\n\rAnyChainBlock\x12!\n\x0cnative_bytes\x18\x01 \x01(\x0cR\x0bnativeBytes\x12:\n\x07\x63\x61rdano\x18\x02 \x01(\x0b\x32\x1e.utxorpc.v1alpha.cardano.BlockH\x00R\x07\x63\x61rdanoB\x07\n\x05\x63hain\"\x80\x01\n\x11\x46\x65tchBlockRequest\x12\x30\n\x03ref\x18\x01 \x03(\x0b\x32\x1e.utxorpc.v1alpha.sync.BlockRefR\x03ref\x12\x39\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\tfieldMask\"O\n\x12\x46\x65tchBlockResponse\x12\x39\n\x05\x62lock\x18\x01 \x03(\x0b\x32#.utxorpc.v1alpha.sync.AnyChainBlockR\x05\x62lock\"\xad\x01\n\x12\x44umpHistoryRequest\x12?\n\x0bstart_token\x18\x02 \x01(\x0b\x32\x1e.utxorpc.v1alpha.sync.BlockRefR\nstartToken\x12\x1b\n\tmax_items\x18\x03 \x01(\rR\x08maxItems\x12\x39\n\nfield_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\tfieldMask\"\x8f\x01\n\x13\x44umpHistoryResponse\x12\x39\n\x05\x62lock\x18\x01 \x03(\x0b\x32#.utxorpc.v1alpha.sync.AnyChainBlockR\x05\x62lock\x12=\n\nnext_token\x18\x02 \x01(\x0b\x32\x1e.utxorpc.v1alpha.sync.BlockRefR\tnextToken\"\x8b\x01\n\x10\x46ollowTipRequest\x12<\n\tintersect\x18\x01 \x03(\x0b\x32\x1e.utxorpc.v1alpha.sync.BlockRefR\tintersect\x12\x39\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\tfieldMask\"\xcd\x01\n\x11\x46ollowTipResponse\x12;\n\x05\x61pply\x18\x01 \x01(\x0b\x32#.utxorpc.v1alpha.sync.AnyChainBlockH\x00R\x05\x61pply\x12\x39\n\x04undo\x18\x02 \x01(\x0b\x32#.utxorpc.v1alpha.sync.AnyChainBlockH\x00R\x04undo\x12\x36\n\x05reset\x18\x03 \x01(\x0b\x32\x1e.utxorpc.v1alpha.sync.BlockRefH\x00R\x05resetB\x08\n\x06\x61\x63tion2\xb2\x02\n\x0bSyncService\x12_\n\nFetchBlock\x12\'.utxorpc.v1alpha.sync.FetchBlockRequest\x1a(.utxorpc.v1alpha.sync.FetchBlockResponse\x12\x62\n\x0b\x44umpHistory\x12(.utxorpc.v1alpha.sync.DumpHistoryRequest\x1a).utxorpc.v1alpha.sync.DumpHistoryResponse\x12^\n\tFollowTip\x12&.utxorpc.v1alpha.sync.FollowTipRequest\x1a\'.utxorpc.v1alpha.sync.FollowTipResponse0\x01\x42\xcb\x01\n\x18\x63om.utxorpc.v1alpha.syncB\tSyncProtoP\x01Z2github.com/utxorpc/go-codegen/utxorpc/v1alpha/sync\xa2\x02\x03UVS\xaa\x02\x14Utxorpc.V1alpha.Sync\xca\x02\x14Utxorpc\\V1alpha\\Sync\xe2\x02 Utxorpc\\V1alpha\\Sync\\GPBMetadata\xea\x02\x16Utxorpc::V1alpha::Syncb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'utxorpc.v1alpha.sync.sync_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\030com.utxorpc.v1alpha.syncB\tSyncProtoP\001Z2github.com/utxorpc/go-codegen/utxorpc/v1alpha/sync\242\002\003UVS\252\002\024Utxorpc.V1alpha.Sync\312\002\024Utxorpc\\V1alpha\\Sync\342\002 Utxorpc\\V1alpha\\Sync\\GPBMetadata\352\002\026Utxorpc::V1alpha::Sync'
  _globals['_BLOCKREF']._serialized_start=130
  _globals['_BLOCKREF']._serialized_end=182
  _globals['_ANYCHAINBLOCK']._serialized_start=184
  _globals['_ANYCHAINBLOCK']._serialized_end=303
  _globals['_FETCHBLOCKREQUEST']._serialized_start=306
  _globals['_FETCHBLOCKREQUEST']._serialized_end=434
  _globals['_FETCHBLOCKRESPONSE']._serialized_start=436
  _globals['_FETCHBLOCKRESPONSE']._serialized_end=515
  _globals['_DUMPHISTORYREQUEST']._serialized_start=518
  _globals['_DUMPHISTORYREQUEST']._serialized_end=691
  _globals['_DUMPHISTORYRESPONSE']._serialized_start=694
  _globals['_DUMPHISTORYRESPONSE']._serialized_end=837
  _globals['_FOLLOWTIPREQUEST']._serialized_start=840
  _globals['_FOLLOWTIPREQUEST']._serialized_end=979
  _globals['_FOLLOWTIPRESPONSE']._serialized_start=982
  _globals['_FOLLOWTIPRESPONSE']._serialized_end=1187
  _globals['_SYNCSERVICE']._serialized_start=1190
  _globals['_SYNCSERVICE']._serialized_end=1496
# @@protoc_insertion_point(module_scope)
