# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: utxorpc/v1alpha/cardano/cardano.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'utxorpc/v1alpha/cardano/cardano.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%utxorpc/v1alpha/cardano/cardano.proto\x12\x17utxorpc.v1alpha.cardano\"\x8d\x01\n\x08Redeemer\x12\x42\n\x07purpose\x18\x01 \x01(\x0e\x32(.utxorpc.v1alpha.cardano.RedeemerPurposeR\x07purpose\x12=\n\x07payload\x18\x02 \x01(\x0b\x32#.utxorpc.v1alpha.cardano.PlutusDataR\x07payload\"\xc4\x01\n\x07TxInput\x12\x17\n\x07tx_hash\x18\x01 \x01(\x0cR\x06txHash\x12!\n\x0coutput_index\x18\x02 \x01(\rR\x0boutputIndex\x12>\n\tas_output\x18\x03 \x01(\x0b\x32!.utxorpc.v1alpha.cardano.TxOutputR\x08\x61sOutput\x12=\n\x08redeemer\x18\x04 \x01(\x0b\x32!.utxorpc.v1alpha.cardano.RedeemerR\x08redeemer\"\xe4\x01\n\x08TxOutput\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0cR\x07\x61\x64\x64ress\x12\x12\n\x04\x63oin\x18\x02 \x01(\x04R\x04\x63oin\x12;\n\x06\x61ssets\x18\x03 \x03(\x0b\x32#.utxorpc.v1alpha.cardano.MultiassetR\x06\x61ssets\x12\x34\n\x05\x64\x61tum\x18\x04 \x01(\x0b\x32\x1e.utxorpc.v1alpha.cardano.DatumR\x05\x64\x61tum\x12\x37\n\x06script\x18\x05 \x01(\x0b\x32\x1f.utxorpc.v1alpha.cardano.ScriptR\x06script\"\x7f\n\x05\x44\x61tum\x12\x12\n\x04hash\x18\x01 \x01(\x0cR\x04hash\x12=\n\x07payload\x18\x02 \x01(\x0b\x32#.utxorpc.v1alpha.cardano.PlutusDataR\x07payload\x12#\n\roriginal_cbor\x18\x03 \x01(\x0cR\x0coriginalCbor\"Y\n\x05\x41sset\x12\x12\n\x04name\x18\x01 \x01(\x0cR\x04name\x12\x1f\n\x0boutput_coin\x18\x02 \x01(\x04R\noutputCoin\x12\x1b\n\tmint_coin\x18\x03 \x01(\x03R\x08mintCoin\"\xa0\x01\n\nMultiasset\x12\x1b\n\tpolicy_id\x18\x01 \x01(\x0cR\x08policyId\x12\x36\n\x06\x61ssets\x18\x02 \x03(\x0b\x32\x1e.utxorpc.v1alpha.cardano.AssetR\x06\x61ssets\x12=\n\x08redeemer\x18\x03 \x01(\x0b\x32!.utxorpc.v1alpha.cardano.RedeemerR\x08redeemer\"4\n\nTxValidity\x12\x14\n\x05start\x18\x01 \x01(\x04R\x05start\x12\x10\n\x03ttl\x18\x02 \x01(\x04R\x03ttl\"\xc9\x01\n\nCollateral\x12@\n\ncollateral\x18\x01 \x03(\x0b\x32 .utxorpc.v1alpha.cardano.TxInputR\ncollateral\x12N\n\x11\x63ollateral_return\x18\x02 \x01(\x0b\x32!.utxorpc.v1alpha.cardano.TxOutputR\x10\x63ollateralReturn\x12)\n\x10total_collateral\x18\x03 \x01(\x04R\x0ftotalCollateral\"\x86\x01\n\nWithdrawal\x12%\n\x0ereward_account\x18\x01 \x01(\x0cR\rrewardAccount\x12\x12\n\x04\x63oin\x18\x02 \x01(\x04R\x04\x63oin\x12=\n\x08redeemer\x18\x03 \x01(\x0b\x32!.utxorpc.v1alpha.cardano.RedeemerR\x08redeemer\"\xd7\x01\n\nWitnessSet\x12\x46\n\x0bvkeywitness\x18\x01 \x03(\x0b\x32$.utxorpc.v1alpha.cardano.VKeyWitnessR\x0bvkeywitness\x12\x37\n\x06script\x18\x02 \x03(\x0b\x32\x1f.utxorpc.v1alpha.cardano.ScriptR\x06script\x12H\n\rplutus_datums\x18\x03 \x03(\x0b\x32#.utxorpc.v1alpha.cardano.PlutusDataR\x0cplutusDatums\"\x83\x01\n\x07\x41uxData\x12=\n\x08metadata\x18\x01 \x03(\x0b\x32!.utxorpc.v1alpha.cardano.MetadataR\x08metadata\x12\x39\n\x07scripts\x18\x02 \x03(\x0b\x32\x1f.utxorpc.v1alpha.cardano.ScriptR\x07scripts\"\xe1\x05\n\x02Tx\x12\x38\n\x06inputs\x18\x01 \x03(\x0b\x32 .utxorpc.v1alpha.cardano.TxInputR\x06inputs\x12;\n\x07outputs\x18\x02 \x03(\x0b\x32!.utxorpc.v1alpha.cardano.TxOutputR\x07outputs\x12H\n\x0c\x63\x65rtificates\x18\x03 \x03(\x0b\x32$.utxorpc.v1alpha.cardano.CertificateR\x0c\x63\x65rtificates\x12\x45\n\x0bwithdrawals\x18\x04 \x03(\x0b\x32#.utxorpc.v1alpha.cardano.WithdrawalR\x0bwithdrawals\x12\x37\n\x04mint\x18\x05 \x03(\x0b\x32#.utxorpc.v1alpha.cardano.MultiassetR\x04mint\x12K\n\x10reference_inputs\x18\x06 \x03(\x0b\x32 .utxorpc.v1alpha.cardano.TxInputR\x0freferenceInputs\x12\x41\n\twitnesses\x18\x07 \x01(\x0b\x32#.utxorpc.v1alpha.cardano.WitnessSetR\twitnesses\x12\x43\n\ncollateral\x18\x08 \x01(\x0b\x32#.utxorpc.v1alpha.cardano.CollateralR\ncollateral\x12\x10\n\x03\x66\x65\x65\x18\t \x01(\x04R\x03\x66\x65\x65\x12?\n\x08validity\x18\n \x01(\x0b\x32#.utxorpc.v1alpha.cardano.TxValidityR\x08validity\x12\x1e\n\nsuccessful\x18\x0b \x01(\x08R\nsuccessful\x12>\n\tauxiliary\x18\x0c \x01(\x0b\x32 .utxorpc.v1alpha.cardano.AuxDataR\tauxiliary\x12\x12\n\x04hash\x18\r \x01(\x0cR\x04hash\"M\n\x0b\x42lockHeader\x12\x12\n\x04slot\x18\x01 \x01(\x04R\x04slot\x12\x12\n\x04hash\x18\x02 \x01(\x0cR\x04hash\x12\x16\n\x06height\x18\x03 \x01(\x04R\x06height\"8\n\tBlockBody\x12+\n\x02tx\x18\x01 \x03(\x0b\x32\x1b.utxorpc.v1alpha.cardano.TxR\x02tx\"}\n\x05\x42lock\x12<\n\x06header\x18\x01 \x01(\x0b\x32$.utxorpc.v1alpha.cardano.BlockHeaderR\x06header\x12\x36\n\x04\x62ody\x18\x02 \x01(\x0b\x32\".utxorpc.v1alpha.cardano.BlockBodyR\x04\x62ody\"?\n\x0bVKeyWitness\x12\x12\n\x04vkey\x18\x01 \x01(\x0cR\x04vkey\x12\x1c\n\tsignature\x18\x02 \x01(\x0cR\tsignature\"\x80\x03\n\x0cNativeScript\x12%\n\rscript_pubkey\x18\x01 \x01(\x0cH\x00R\x0cscriptPubkey\x12J\n\nscript_all\x18\x02 \x01(\x0b\x32).utxorpc.v1alpha.cardano.NativeScriptListH\x00R\tscriptAll\x12J\n\nscript_any\x18\x03 \x01(\x0b\x32).utxorpc.v1alpha.cardano.NativeScriptListH\x00R\tscriptAny\x12H\n\rscript_n_of_k\x18\x04 \x01(\x0b\x32#.utxorpc.v1alpha.cardano.ScriptNOfKH\x00R\nscriptNOfK\x12\'\n\x0einvalid_before\x18\x05 \x01(\x04H\x00R\rinvalidBefore\x12-\n\x11invalid_hereafter\x18\x06 \x01(\x04H\x00R\x10invalidHereafterB\x0f\n\rnative_script\"O\n\x10NativeScriptList\x12;\n\x05items\x18\x01 \x03(\x0b\x32%.utxorpc.v1alpha.cardano.NativeScriptR\x05items\"[\n\nScriptNOfK\x12\x0c\n\x01k\x18\x01 \x01(\rR\x01k\x12?\n\x07scripts\x18\x02 \x03(\x0b\x32%.utxorpc.v1alpha.cardano.NativeScriptR\x07scripts\"\x80\x01\n\x06\x43onstr\x12\x10\n\x03tag\x18\x01 \x01(\rR\x03tag\x12\'\n\x0f\x61ny_constructor\x18\x02 \x01(\x04R\x0e\x61nyConstructor\x12;\n\x06\x66ields\x18\x03 \x03(\x0b\x32#.utxorpc.v1alpha.cardano.PlutusDataR\x06\x66ields\"c\n\x06\x42igInt\x12\x12\n\x03int\x18\x01 \x01(\x03H\x00R\x03int\x12\x1c\n\tbig_u_int\x18\x02 \x01(\x0cH\x00R\x07\x62igUInt\x12\x1c\n\tbig_n_int\x18\x03 \x01(\x0cH\x00R\x07\x62igNIntB\t\n\x07\x62ig_int\"\x82\x01\n\x0ePlutusDataPair\x12\x35\n\x03key\x18\x01 \x01(\x0b\x32#.utxorpc.v1alpha.cardano.PlutusDataR\x03key\x12\x39\n\x05value\x18\x02 \x01(\x0b\x32#.utxorpc.v1alpha.cardano.PlutusDataR\x05value\"\xb7\x02\n\nPlutusData\x12\x39\n\x06\x63onstr\x18\x02 \x01(\x0b\x32\x1f.utxorpc.v1alpha.cardano.ConstrH\x00R\x06\x63onstr\x12:\n\x03map\x18\x03 \x01(\x0b\x32&.utxorpc.v1alpha.cardano.PlutusDataMapH\x00R\x03map\x12:\n\x07\x62ig_int\x18\x04 \x01(\x0b\x32\x1f.utxorpc.v1alpha.cardano.BigIntH\x00R\x06\x62igInt\x12%\n\rbounded_bytes\x18\x05 \x01(\x0cH\x00R\x0c\x62oundedBytes\x12@\n\x05\x61rray\x18\x06 \x01(\x0b\x32(.utxorpc.v1alpha.cardano.PlutusDataArrayH\x00R\x05\x61rrayB\r\n\x0bplutus_data\"N\n\rPlutusDataMap\x12=\n\x05pairs\x18\x01 \x03(\x0b\x32\'.utxorpc.v1alpha.cardano.PlutusDataPairR\x05pairs\"L\n\x0fPlutusDataArray\x12\x39\n\x05items\x18\x01 \x03(\x0b\x32#.utxorpc.v1alpha.cardano.PlutusDataR\x05items\"\x91\x01\n\x06Script\x12?\n\x06native\x18\x01 \x01(\x0b\x32%.utxorpc.v1alpha.cardano.NativeScriptH\x00R\x06native\x12\x1d\n\tplutus_v1\x18\x02 \x01(\x0cH\x00R\x08plutusV1\x12\x1d\n\tplutus_v2\x18\x03 \x01(\x0cH\x00R\x08plutusV2B\x08\n\x06script\"\xd6\x01\n\tMetadatum\x12\x12\n\x03int\x18\x01 \x01(\x03H\x00R\x03int\x12\x16\n\x05\x62ytes\x18\x02 \x01(\x0cH\x00R\x05\x62ytes\x12\x14\n\x04text\x18\x03 \x01(\tH\x00R\x04text\x12?\n\x05\x61rray\x18\x04 \x01(\x0b\x32\'.utxorpc.v1alpha.cardano.MetadatumArrayH\x00R\x05\x61rray\x12\x39\n\x03map\x18\x05 \x01(\x0b\x32%.utxorpc.v1alpha.cardano.MetadatumMapH\x00R\x03mapB\x0b\n\tmetadatum\"J\n\x0eMetadatumArray\x12\x38\n\x05items\x18\x01 \x03(\x0b\x32\".utxorpc.v1alpha.cardano.MetadatumR\x05items\"L\n\x0cMetadatumMap\x12<\n\x05pairs\x18\x01 \x03(\x0b\x32&.utxorpc.v1alpha.cardano.MetadatumPairR\x05pairs\"\x7f\n\rMetadatumPair\x12\x34\n\x03key\x18\x01 \x01(\x0b\x32\".utxorpc.v1alpha.cardano.MetadatumR\x03key\x12\x38\n\x05value\x18\x02 \x01(\x0b\x32\".utxorpc.v1alpha.cardano.MetadatumR\x05value\"Z\n\x08Metadata\x12\x14\n\x05label\x18\x01 \x01(\x04R\x05label\x12\x38\n\x05value\x18\x02 \x01(\x0b\x32\".utxorpc.v1alpha.cardano.MetadatumR\x05value\"n\n\x0fStakeCredential\x12$\n\raddr_key_hash\x18\x01 \x01(\x0cH\x00R\x0b\x61\x64\x64rKeyHash\x12!\n\x0bscript_hash\x18\x02 \x01(\x0cH\x00R\nscriptHashB\x12\n\x10stake_credential\"P\n\x0eRationalNumber\x12\x1c\n\tnumerator\x18\x01 \x01(\x05R\tnumerator\x12 \n\x0b\x64\x65nominator\x18\x02 \x01(\rR\x0b\x64\x65nominator\"`\n\x05Relay\x12\x13\n\x05ip_v4\x18\x01 \x01(\x0cR\x04ipV4\x12\x13\n\x05ip_v6\x18\x02 \x01(\x0cR\x04ipV6\x12\x19\n\x08\x64ns_name\x18\x03 \x01(\tR\x07\x64nsName\x12\x12\n\x04port\x18\x04 \x01(\rR\x04port\"4\n\x0cPoolMetadata\x12\x10\n\x03url\x18\x01 \x01(\tR\x03url\x12\x12\n\x04hash\x18\x02 \x01(\x0cR\x04hash\"\xd0\x05\n\x0b\x43\x65rtificate\x12Y\n\x12stake_registration\x18\x01 \x01(\x0b\x32(.utxorpc.v1alpha.cardano.StakeCredentialH\x00R\x11stakeRegistration\x12]\n\x14stake_deregistration\x18\x02 \x01(\x0b\x32(.utxorpc.v1alpha.cardano.StakeCredentialH\x00R\x13stakeDeregistration\x12Y\n\x10stake_delegation\x18\x03 \x01(\x0b\x32,.utxorpc.v1alpha.cardano.StakeDelegationCertH\x00R\x0fstakeDelegation\x12\\\n\x11pool_registration\x18\x04 \x01(\x0b\x32-.utxorpc.v1alpha.cardano.PoolRegistrationCertH\x00R\x10poolRegistration\x12V\n\x0fpool_retirement\x18\x05 \x01(\x0b\x32+.utxorpc.v1alpha.cardano.PoolRetirementCertH\x00R\x0epoolRetirement\x12i\n\x16genesis_key_delegation\x18\x06 \x01(\x0b\x32\x31.utxorpc.v1alpha.cardano.GenesisKeyDelegationCertH\x00R\x14genesisKeyDelegation\x12=\n\x08mir_cert\x18\x07 \x01(\x0b\x32 .utxorpc.v1alpha.cardano.MirCertH\x00R\x07mirCert\x12=\n\x08redeemer\x18\x64 \x01(\x0b\x32!.utxorpc.v1alpha.cardano.RedeemerR\x08redeemerB\r\n\x0b\x63\x65rtificate\"\x8d\x01\n\x13StakeDelegationCert\x12S\n\x10stake_credential\x18\x01 \x01(\x0b\x32(.utxorpc.v1alpha.cardano.StakeCredentialR\x0fstakeCredential\x12!\n\x0cpool_keyhash\x18\x02 \x01(\x0cR\x0bpoolKeyhash\"\x8c\x03\n\x14PoolRegistrationCert\x12\x1a\n\x08operator\x18\x01 \x01(\x0cR\x08operator\x12\x1f\n\x0bvrf_keyhash\x18\x02 \x01(\x0cR\nvrfKeyhash\x12\x16\n\x06pledge\x18\x03 \x01(\x04R\x06pledge\x12\x12\n\x04\x63ost\x18\x04 \x01(\x04R\x04\x63ost\x12?\n\x06margin\x18\x05 \x01(\x0b\x32\'.utxorpc.v1alpha.cardano.RationalNumberR\x06margin\x12%\n\x0ereward_account\x18\x06 \x01(\x0cR\rrewardAccount\x12\x1f\n\x0bpool_owners\x18\x07 \x03(\x0cR\npoolOwners\x12\x36\n\x06relays\x18\x08 \x03(\x0b\x32\x1e.utxorpc.v1alpha.cardano.RelayR\x06relays\x12J\n\rpool_metadata\x18\t \x01(\x0b\x32%.utxorpc.v1alpha.cardano.PoolMetadataR\x0cpoolMetadata\"M\n\x12PoolRetirementCert\x12!\n\x0cpool_keyhash\x18\x01 \x01(\x0cR\x0bpoolKeyhash\x12\x14\n\x05\x65poch\x18\x02 \x01(\x04R\x05\x65poch\"\x92\x01\n\x18GenesisKeyDelegationCert\x12!\n\x0cgenesis_hash\x18\x01 \x01(\x0cR\x0bgenesisHash\x12\x32\n\x15genesis_delegate_hash\x18\x02 \x01(\x0cR\x13genesisDelegateHash\x12\x1f\n\x0bvrf_keyhash\x18\x03 \x01(\x0cR\nvrfKeyhash\"\x7f\n\tMirTarget\x12S\n\x10stake_credential\x18\x01 \x01(\x0b\x32(.utxorpc.v1alpha.cardano.StakeCredentialR\x0fstakeCredential\x12\x1d\n\ndelta_coin\x18\x02 \x01(\x03R\tdeltaCoin\"\x92\x01\n\x07MirCert\x12\x36\n\x04\x66rom\x18\x01 \x01(\x0e\x32\".utxorpc.v1alpha.cardano.MirSourceR\x04\x66rom\x12\x32\n\x02to\x18\x02 \x03(\x0b\x32\".utxorpc.v1alpha.cardano.MirTargetR\x02to\x12\x1b\n\tother_pot\x18\x03 \x01(\x04R\x08otherPot\"\x81\x01\n\x0e\x41\x64\x64ressPattern\x12#\n\rexact_address\x18\x01 \x01(\x0cR\x0c\x65xactAddress\x12!\n\x0cpayment_part\x18\x02 \x01(\x0cR\x0bpaymentPart\x12\'\n\x0f\x64\x65legation_part\x18\x03 \x01(\x0cR\x0e\x64\x65legationPart\"J\n\x0c\x41ssetPattern\x12\x1b\n\tpolicy_id\x18\x01 \x01(\x0cR\x08policyId\x12\x1d\n\nasset_name\x18\x02 \x01(\x0cR\tassetName\"\x91\x01\n\x0fTxOutputPattern\x12\x41\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\'.utxorpc.v1alpha.cardano.AddressPatternR\x07\x61\x64\x64ress\x12;\n\x05\x61sset\x18\x02 \x01(\x0b\x32%.utxorpc.v1alpha.cardano.AssetPatternR\x05\x61sset\"\xf1\x02\n\tTxPattern\x12\x44\n\x08\x63onsumes\x18\x01 \x01(\x0b\x32(.utxorpc.v1alpha.cardano.TxOutputPatternR\x08\x63onsumes\x12\x44\n\x08produces\x18\x02 \x01(\x0b\x32(.utxorpc.v1alpha.cardano.TxOutputPatternR\x08produces\x12H\n\x0bhas_address\x18\x03 \x01(\x0b\x32\'.utxorpc.v1alpha.cardano.AddressPatternR\nhasAddress\x12\x46\n\x0bmoves_asset\x18\x04 \x01(\x0b\x32%.utxorpc.v1alpha.cardano.AssetPatternR\nmovesAsset\x12\x46\n\x0bmints_asset\x18\x05 \x01(\x0b\x32%.utxorpc.v1alpha.cardano.AssetPatternR\nmintsAsset\"7\n\x07\x45xUnits\x12\x14\n\x05steps\x18\x01 \x01(\x04R\x05steps\x12\x16\n\x06memory\x18\x02 \x01(\x04R\x06memory\"\x8a\x01\n\x08\x45xPrices\x12=\n\x05steps\x18\x01 \x01(\x0b\x32\'.utxorpc.v1alpha.cardano.RationalNumberR\x05steps\x12?\n\x06memory\x18\x02 \x01(\x0b\x32\'.utxorpc.v1alpha.cardano.RationalNumberR\x06memory\"=\n\x0fProtocolVersion\x12\x14\n\x05major\x18\x01 \x01(\rR\x05major\x12\x14\n\x05minor\x18\x02 \x01(\rR\x05minor\"#\n\tCostModel\x12\x16\n\x06values\x18\x01 \x03(\x03R\x06values\"\x8e\x01\n\nCostModels\x12?\n\tplutus_v1\x18\x01 \x01(\x0b\x32\".utxorpc.v1alpha.cardano.CostModelR\x08plutusV1\x12?\n\tplutus_v2\x18\x02 \x01(\x0b\x32\".utxorpc.v1alpha.cardano.CostModelR\x08plutusV2\"\xb6\n\n\x07PParams\x12-\n\x13\x63oins_per_utxo_byte\x18\x01 \x01(\x04R\x10\x63oinsPerUtxoByte\x12\x1e\n\x0bmax_tx_size\x18\x02 \x01(\x04R\tmaxTxSize\x12.\n\x13min_fee_coefficient\x18\x03 \x01(\x04R\x11minFeeCoefficient\x12(\n\x10min_fee_constant\x18\x04 \x01(\x04R\x0eminFeeConstant\x12-\n\x13max_block_body_size\x18\x05 \x01(\x04R\x10maxBlockBodySize\x12\x31\n\x15max_block_header_size\x18\x06 \x01(\x04R\x12maxBlockHeaderSize\x12*\n\x11stake_key_deposit\x18\x07 \x01(\x04R\x0fstakeKeyDeposit\x12!\n\x0cpool_deposit\x18\x08 \x01(\x04R\x0bpoolDeposit\x12=\n\x1bpool_retirement_epoch_bound\x18\t \x01(\x04R\x18poolRetirementEpochBound\x12\x35\n\x17\x64\x65sired_number_of_pools\x18\n \x01(\x04R\x14\x64\x65siredNumberOfPools\x12N\n\x0epool_influence\x18\x0b \x01(\x0b\x32\'.utxorpc.v1alpha.cardano.RationalNumberR\rpoolInfluence\x12V\n\x12monetary_expansion\x18\x0c \x01(\x0b\x32\'.utxorpc.v1alpha.cardano.RationalNumberR\x11monetaryExpansion\x12V\n\x12treasury_expansion\x18\r \x01(\x0b\x32\'.utxorpc.v1alpha.cardano.RationalNumberR\x11treasuryExpansion\x12\"\n\rmin_pool_cost\x18\x0e \x01(\x04R\x0bminPoolCost\x12S\n\x10protocol_version\x18\x0f \x01(\x0b\x32(.utxorpc.v1alpha.cardano.ProtocolVersionR\x0fprotocolVersion\x12$\n\x0emax_value_size\x18\x10 \x01(\x04R\x0cmaxValueSize\x12\x33\n\x15\x63ollateral_percentage\x18\x11 \x01(\x04R\x14\x63ollateralPercentage\x12\x32\n\x15max_collateral_inputs\x18\x12 \x01(\x04R\x13maxCollateralInputs\x12\x44\n\x0b\x63ost_models\x18\x13 \x01(\x0b\x32#.utxorpc.v1alpha.cardano.CostModelsR\ncostModels\x12\x39\n\x06prices\x18\x14 \x01(\x0b\x32!.utxorpc.v1alpha.cardano.ExPricesR\x06prices\x12n\n#max_execution_units_per_transaction\x18\x15 \x01(\x0b\x32 .utxorpc.v1alpha.cardano.ExUnitsR\x1fmaxExecutionUnitsPerTransaction\x12\x62\n\x1dmax_execution_units_per_block\x18\x16 \x01(\x0b\x32 .utxorpc.v1alpha.cardano.ExUnitsR\x19maxExecutionUnitsPerBlock\"\x1d\n\tEvalError\x12\x10\n\x03msg\x18\x01 \x01(\tR\x03msg\"\x1d\n\tEvalTrace\x12\x10\n\x03msg\x18\x01 \x01(\tR\x03msg\"\xcf\x01\n\x06TxEval\x12\x10\n\x03\x66\x65\x65\x18\x01 \x01(\x04R\x03\x66\x65\x65\x12;\n\x08\x65x_units\x18\x02 \x01(\x0b\x32 .utxorpc.v1alpha.cardano.ExUnitsR\x07\x65xUnits\x12:\n\x06\x65rrors\x18\x03 \x03(\x0b\x32\".utxorpc.v1alpha.cardano.EvalErrorR\x06\x65rrors\x12:\n\x06traces\x18\x04 \x03(\x0b\x32\".utxorpc.v1alpha.cardano.EvalTraceR\x06traces*\xa2\x01\n\x0fRedeemerPurpose\x12 \n\x1cREDEEMER_PURPOSE_UNSPECIFIED\x10\x00\x12\x1a\n\x16REDEEMER_PURPOSE_SPEND\x10\x01\x12\x19\n\x15REDEEMER_PURPOSE_MINT\x10\x02\x12\x19\n\x15REDEEMER_PURPOSE_CERT\x10\x03\x12\x1b\n\x17REDEEMER_PURPOSE_REWARD\x10\x04*Y\n\tMirSource\x12\x1a\n\x16MIR_SOURCE_UNSPECIFIED\x10\x00\x12\x17\n\x13MIR_SOURCE_RESERVES\x10\x01\x12\x17\n\x13MIR_SOURCE_TREASURY\x10\x02\x42\xe0\x01\n\x1b\x63om.utxorpc.v1alpha.cardanoB\x0c\x43\x61rdanoProtoP\x01Z5github.com/utxorpc/go-codegen/utxorpc/v1alpha/cardano\xa2\x02\x03UVC\xaa\x02\x17Utxorpc.V1alpha.Cardano\xca\x02\x17Utxorpc\\V1alpha\\Cardano\xe2\x02#Utxorpc\\V1alpha\\Cardano\\GPBMetadata\xea\x02\x19Utxorpc::V1alpha::Cardanob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'utxorpc.v1alpha.cardano.cardano_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033com.utxorpc.v1alpha.cardanoB\014CardanoProtoP\001Z5github.com/utxorpc/go-codegen/utxorpc/v1alpha/cardano\242\002\003UVC\252\002\027Utxorpc.V1alpha.Cardano\312\002\027Utxorpc\\V1alpha\\Cardano\342\002#Utxorpc\\V1alpha\\Cardano\\GPBMetadata\352\002\031Utxorpc::V1alpha::Cardano'
  _globals['_REDEEMERPURPOSE']._serialized_start=9876
  _globals['_REDEEMERPURPOSE']._serialized_end=10038
  _globals['_MIRSOURCE']._serialized_start=10040
  _globals['_MIRSOURCE']._serialized_end=10129
  _globals['_REDEEMER']._serialized_start=67
  _globals['_REDEEMER']._serialized_end=208
  _globals['_TXINPUT']._serialized_start=211
  _globals['_TXINPUT']._serialized_end=407
  _globals['_TXOUTPUT']._serialized_start=410
  _globals['_TXOUTPUT']._serialized_end=638
  _globals['_DATUM']._serialized_start=640
  _globals['_DATUM']._serialized_end=767
  _globals['_ASSET']._serialized_start=769
  _globals['_ASSET']._serialized_end=858
  _globals['_MULTIASSET']._serialized_start=861
  _globals['_MULTIASSET']._serialized_end=1021
  _globals['_TXVALIDITY']._serialized_start=1023
  _globals['_TXVALIDITY']._serialized_end=1075
  _globals['_COLLATERAL']._serialized_start=1078
  _globals['_COLLATERAL']._serialized_end=1279
  _globals['_WITHDRAWAL']._serialized_start=1282
  _globals['_WITHDRAWAL']._serialized_end=1416
  _globals['_WITNESSSET']._serialized_start=1419
  _globals['_WITNESSSET']._serialized_end=1634
  _globals['_AUXDATA']._serialized_start=1637
  _globals['_AUXDATA']._serialized_end=1768
  _globals['_TX']._serialized_start=1771
  _globals['_TX']._serialized_end=2508
  _globals['_BLOCKHEADER']._serialized_start=2510
  _globals['_BLOCKHEADER']._serialized_end=2587
  _globals['_BLOCKBODY']._serialized_start=2589
  _globals['_BLOCKBODY']._serialized_end=2645
  _globals['_BLOCK']._serialized_start=2647
  _globals['_BLOCK']._serialized_end=2772
  _globals['_VKEYWITNESS']._serialized_start=2774
  _globals['_VKEYWITNESS']._serialized_end=2837
  _globals['_NATIVESCRIPT']._serialized_start=2840
  _globals['_NATIVESCRIPT']._serialized_end=3224
  _globals['_NATIVESCRIPTLIST']._serialized_start=3226
  _globals['_NATIVESCRIPTLIST']._serialized_end=3305
  _globals['_SCRIPTNOFK']._serialized_start=3307
  _globals['_SCRIPTNOFK']._serialized_end=3398
  _globals['_CONSTR']._serialized_start=3401
  _globals['_CONSTR']._serialized_end=3529
  _globals['_BIGINT']._serialized_start=3531
  _globals['_BIGINT']._serialized_end=3630
  _globals['_PLUTUSDATAPAIR']._serialized_start=3633
  _globals['_PLUTUSDATAPAIR']._serialized_end=3763
  _globals['_PLUTUSDATA']._serialized_start=3766
  _globals['_PLUTUSDATA']._serialized_end=4077
  _globals['_PLUTUSDATAMAP']._serialized_start=4079
  _globals['_PLUTUSDATAMAP']._serialized_end=4157
  _globals['_PLUTUSDATAARRAY']._serialized_start=4159
  _globals['_PLUTUSDATAARRAY']._serialized_end=4235
  _globals['_SCRIPT']._serialized_start=4238
  _globals['_SCRIPT']._serialized_end=4383
  _globals['_METADATUM']._serialized_start=4386
  _globals['_METADATUM']._serialized_end=4600
  _globals['_METADATUMARRAY']._serialized_start=4602
  _globals['_METADATUMARRAY']._serialized_end=4676
  _globals['_METADATUMMAP']._serialized_start=4678
  _globals['_METADATUMMAP']._serialized_end=4754
  _globals['_METADATUMPAIR']._serialized_start=4756
  _globals['_METADATUMPAIR']._serialized_end=4883
  _globals['_METADATA']._serialized_start=4885
  _globals['_METADATA']._serialized_end=4975
  _globals['_STAKECREDENTIAL']._serialized_start=4977
  _globals['_STAKECREDENTIAL']._serialized_end=5087
  _globals['_RATIONALNUMBER']._serialized_start=5089
  _globals['_RATIONALNUMBER']._serialized_end=5169
  _globals['_RELAY']._serialized_start=5171
  _globals['_RELAY']._serialized_end=5267
  _globals['_POOLMETADATA']._serialized_start=5269
  _globals['_POOLMETADATA']._serialized_end=5321
  _globals['_CERTIFICATE']._serialized_start=5324
  _globals['_CERTIFICATE']._serialized_end=6044
  _globals['_STAKEDELEGATIONCERT']._serialized_start=6047
  _globals['_STAKEDELEGATIONCERT']._serialized_end=6188
  _globals['_POOLREGISTRATIONCERT']._serialized_start=6191
  _globals['_POOLREGISTRATIONCERT']._serialized_end=6587
  _globals['_POOLRETIREMENTCERT']._serialized_start=6589
  _globals['_POOLRETIREMENTCERT']._serialized_end=6666
  _globals['_GENESISKEYDELEGATIONCERT']._serialized_start=6669
  _globals['_GENESISKEYDELEGATIONCERT']._serialized_end=6815
  _globals['_MIRTARGET']._serialized_start=6817
  _globals['_MIRTARGET']._serialized_end=6944
  _globals['_MIRCERT']._serialized_start=6947
  _globals['_MIRCERT']._serialized_end=7093
  _globals['_ADDRESSPATTERN']._serialized_start=7096
  _globals['_ADDRESSPATTERN']._serialized_end=7225
  _globals['_ASSETPATTERN']._serialized_start=7227
  _globals['_ASSETPATTERN']._serialized_end=7301
  _globals['_TXOUTPUTPATTERN']._serialized_start=7304
  _globals['_TXOUTPUTPATTERN']._serialized_end=7449
  _globals['_TXPATTERN']._serialized_start=7452
  _globals['_TXPATTERN']._serialized_end=7821
  _globals['_EXUNITS']._serialized_start=7823
  _globals['_EXUNITS']._serialized_end=7878
  _globals['_EXPRICES']._serialized_start=7881
  _globals['_EXPRICES']._serialized_end=8019
  _globals['_PROTOCOLVERSION']._serialized_start=8021
  _globals['_PROTOCOLVERSION']._serialized_end=8082
  _globals['_COSTMODEL']._serialized_start=8084
  _globals['_COSTMODEL']._serialized_end=8119
  _globals['_COSTMODELS']._serialized_start=8122
  _globals['_COSTMODELS']._serialized_end=8264
  _globals['_PPARAMS']._serialized_start=8267
  _globals['_PPARAMS']._serialized_end=9601
  _globals['_EVALERROR']._serialized_start=9603
  _globals['_EVALERROR']._serialized_end=9632
  _globals['_EVALTRACE']._serialized_start=9634
  _globals['_EVALTRACE']._serialized_end=9663
  _globals['_TXEVAL']._serialized_start=9666
  _globals['_TXEVAL']._serialized_end=9873
# @@protoc_insertion_point(module_scope)
