# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: utxorpc/v1alpha/submit/submit.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'utxorpc/v1alpha/submit/submit.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from utxorpc_spec.utxorpc.v1alpha.cardano import cardano_pb2 as utxorpc_dot_v1alpha_dot_cardano_dot_cardano__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#utxorpc/v1alpha/submit/submit.proto\x12\x16utxorpc.v1alpha.submit\x1a google/protobuf/field_mask.proto\x1a%utxorpc/v1alpha/cardano/cardano.proto\"(\n\nAnyChainTx\x12\x12\n\x03raw\x18\x01 \x01(\x0cH\x00R\x03rawB\x06\n\x04type\"C\n\rEvalTxRequest\x12\x32\n\x02tx\x18\x01 \x03(\x0b\x32\".utxorpc.v1alpha.submit.AnyChainTxR\x02tx\"T\n\x0c\x41nyChainEval\x12;\n\x07\x63\x61rdano\x18\x01 \x01(\x0b\x32\x1f.utxorpc.v1alpha.cardano.TxEvalH\x00R\x07\x63\x61rdanoB\x07\n\x05\x63hain\"N\n\x0e\x45valTxResponse\x12<\n\x06report\x18\x01 \x03(\x0b\x32$.utxorpc.v1alpha.submit.AnyChainEvalR\x06report\"E\n\x0fSubmitTxRequest\x12\x32\n\x02tx\x18\x01 \x03(\x0b\x32\".utxorpc.v1alpha.submit.AnyChainTxR\x02tx\"$\n\x10SubmitTxResponse\x12\x10\n\x03ref\x18\x01 \x03(\x0cR\x03ref\"v\n\x0bTxInMempool\x12\x32\n\x02tx\x18\x01 \x01(\x0b\x32\".utxorpc.v1alpha.submit.AnyChainTxR\x02tx\x12\x33\n\x05stage\x18\x02 \x01(\x0e\x32\x1d.utxorpc.v1alpha.submit.StageR\x05stage\"I\n\x12ReadMempoolRequest\x12\x33\n\x02tx\x18\x01 \x03(\x0b\x32#.utxorpc.v1alpha.submit.TxInMempoolR\x02tx\"J\n\x13ReadMempoolResponse\x12\x33\n\x05stage\x18\x01 \x03(\x0e\x32\x1d.utxorpc.v1alpha.submit.StageR\x05stage\"$\n\x10WaitForTxRequest\x12\x10\n\x03ref\x18\x01 \x03(\x0cR\x03ref\"Z\n\x11WaitForTxResponse\x12\x10\n\x03ref\x18\x01 \x01(\x0cR\x03ref\x12\x33\n\x05stage\x18\x02 \x01(\x0e\x32\x1d.utxorpc.v1alpha.submit.StageR\x05stage\"\\\n\x11\x41nyChainTxPattern\x12>\n\x07\x63\x61rdano\x18\x01 \x01(\x0b\x32\".utxorpc.v1alpha.cardano.TxPatternH\x00R\x07\x63\x61rdanoB\x07\n\x05\x63hain\"\xfd\x01\n\x0bTxPredicate\x12?\n\x05match\x18\x01 \x01(\x0b\x32).utxorpc.v1alpha.submit.AnyChainTxPatternR\x05match\x12\x35\n\x03not\x18\x02 \x03(\x0b\x32#.utxorpc.v1alpha.submit.TxPredicateR\x03not\x12:\n\x06\x61ll_of\x18\x03 \x03(\x0b\x32#.utxorpc.v1alpha.submit.TxPredicateR\x05\x61llOf\x12:\n\x06\x61ny_of\x18\x04 \x03(\x0b\x32#.utxorpc.v1alpha.submit.TxPredicateR\x05\x61nyOf\"\x93\x01\n\x13WatchMempoolRequest\x12\x41\n\tpredicate\x18\x01 \x01(\x0b\x32#.utxorpc.v1alpha.submit.TxPredicateR\tpredicate\x12\x39\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\tfieldMask\"K\n\x14WatchMempoolResponse\x12\x33\n\x02tx\x18\x01 \x01(\x0b\x32#.utxorpc.v1alpha.submit.TxInMempoolR\x02tx*q\n\x05Stage\x12\x15\n\x11STAGE_UNSPECIFIED\x10\x00\x12\x16\n\x12STAGE_ACKNOWLEDGED\x10\x01\x12\x11\n\rSTAGE_MEMPOOL\x10\x02\x12\x11\n\rSTAGE_NETWORK\x10\x03\x12\x13\n\x0fSTAGE_CONFIRMED\x10\x04\x32\x80\x04\n\rSubmitService\x12W\n\x06\x45valTx\x12%.utxorpc.v1alpha.submit.EvalTxRequest\x1a&.utxorpc.v1alpha.submit.EvalTxResponse\x12]\n\x08SubmitTx\x12\'.utxorpc.v1alpha.submit.SubmitTxRequest\x1a(.utxorpc.v1alpha.submit.SubmitTxResponse\x12\x62\n\tWaitForTx\x12(.utxorpc.v1alpha.submit.WaitForTxRequest\x1a).utxorpc.v1alpha.submit.WaitForTxResponse0\x01\x12\x66\n\x0bReadMempool\x12*.utxorpc.v1alpha.submit.ReadMempoolRequest\x1a+.utxorpc.v1alpha.submit.ReadMempoolResponse\x12k\n\x0cWatchMempool\x12+.utxorpc.v1alpha.submit.WatchMempoolRequest\x1a,.utxorpc.v1alpha.submit.WatchMempoolResponse0\x01\x42\xd9\x01\n\x1a\x63om.utxorpc.v1alpha.submitB\x0bSubmitProtoP\x01Z4github.com/utxorpc/go-codegen/utxorpc/v1alpha/submit\xa2\x02\x03UVS\xaa\x02\x16Utxorpc.V1alpha.Submit\xca\x02\x16Utxorpc\\V1alpha\\Submit\xe2\x02\"Utxorpc\\V1alpha\\Submit\\GPBMetadata\xea\x02\x18Utxorpc::V1alpha::Submitb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'utxorpc.v1alpha.submit.submit_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032com.utxorpc.v1alpha.submitB\013SubmitProtoP\001Z4github.com/utxorpc/go-codegen/utxorpc/v1alpha/submit\242\002\003UVS\252\002\026Utxorpc.V1alpha.Submit\312\002\026Utxorpc\\V1alpha\\Submit\342\002\"Utxorpc\\V1alpha\\Submit\\GPBMetadata\352\002\030Utxorpc::V1alpha::Submit'
  _globals['_STAGE']._serialized_start=1500
  _globals['_STAGE']._serialized_end=1613
  _globals['_ANYCHAINTX']._serialized_start=136
  _globals['_ANYCHAINTX']._serialized_end=176
  _globals['_EVALTXREQUEST']._serialized_start=178
  _globals['_EVALTXREQUEST']._serialized_end=245
  _globals['_ANYCHAINEVAL']._serialized_start=247
  _globals['_ANYCHAINEVAL']._serialized_end=331
  _globals['_EVALTXRESPONSE']._serialized_start=333
  _globals['_EVALTXRESPONSE']._serialized_end=411
  _globals['_SUBMITTXREQUEST']._serialized_start=413
  _globals['_SUBMITTXREQUEST']._serialized_end=482
  _globals['_SUBMITTXRESPONSE']._serialized_start=484
  _globals['_SUBMITTXRESPONSE']._serialized_end=520
  _globals['_TXINMEMPOOL']._serialized_start=522
  _globals['_TXINMEMPOOL']._serialized_end=640
  _globals['_READMEMPOOLREQUEST']._serialized_start=642
  _globals['_READMEMPOOLREQUEST']._serialized_end=715
  _globals['_READMEMPOOLRESPONSE']._serialized_start=717
  _globals['_READMEMPOOLRESPONSE']._serialized_end=791
  _globals['_WAITFORTXREQUEST']._serialized_start=793
  _globals['_WAITFORTXREQUEST']._serialized_end=829
  _globals['_WAITFORTXRESPONSE']._serialized_start=831
  _globals['_WAITFORTXRESPONSE']._serialized_end=921
  _globals['_ANYCHAINTXPATTERN']._serialized_start=923
  _globals['_ANYCHAINTXPATTERN']._serialized_end=1015
  _globals['_TXPREDICATE']._serialized_start=1018
  _globals['_TXPREDICATE']._serialized_end=1271
  _globals['_WATCHMEMPOOLREQUEST']._serialized_start=1274
  _globals['_WATCHMEMPOOLREQUEST']._serialized_end=1421
  _globals['_WATCHMEMPOOLRESPONSE']._serialized_start=1423
  _globals['_WATCHMEMPOOLRESPONSE']._serialized_end=1498
  _globals['_SUBMITSERVICE']._serialized_start=1616
  _globals['_SUBMITSERVICE']._serialized_end=2128
# @@protoc_insertion_point(module_scope)
